#include <Arduino.h>
#include <M5Stack.h>
#include "SparkFun_SCD30_Arduino_Library.h"

// ********************************************************************
//  M5StackとSCD30を使ったCO2と温度・湿度がわかる環境モニタ
//  
//  必要な機材
//  ・M5Stack Gray
//  https://shop.m5stack.com/collections/m5-core/products/grey-development-core
//  ・CO2センサー
//  https://wiki.seeedstudio.com/Grove-CO2_Temperature_Humidity_Sensor-SCD30/
//  
//  This software is distributed under the license of NYSL.
//  http://www.kmonos.net/nysl/
// ********************************************************************

uint32_t bg; // 背景色
uint32_t fg; // 描画色

SCD30 sensor; // センサー(SCD30)
uint16_t co2; // センサーから取得したCO2濃度(ppm)
float temp;   // センサーから取得した温度(C)
float hum;    // センサーから取得した湿度(%)

void setup()
{
  // M5Stack初期化
  M5.begin();
  M5.Lcd.begin();
  M5.Lcd.setSwapBytes(true);
  M5.Lcd.setRotation(1);

  // I2C/センサー初期化
  Wire.begin();
  sensor.begin();
  sensor.setAutoSelfCalibration(true);
}

void loop()
{

  // センサーはデータ取得可能か?
  if (sensor.dataAvailable())
  {
    // CO2、温度、湿度を取得
    co2 = sensor.getCO2();
    temp = sensor.getTemperature();
    hum = sensor.getHumidity();

    // CO2濃度に応じて色分け
    if (co2 > 2500)
    {
      bg = TFT_RED;
      fg = TFT_WHITE;
    }
    else if (co2 > 1000)
    {
      bg = TFT_YELLOW;
      fg = TFT_BLACK;
    }
    else
    {
      bg = TFT_BLACK;
      fg = TFT_WHITE;
    }

    // LCD描画開始
    M5.Lcd.startWrite();
    M5.Lcd.fillScreen(bg);
    M5.Lcd.setTextColor(fg);
    // CO2
    M5.Lcd.setTextSize(3);
    M5.Lcd.setCursor(0, 40);
    M5.Lcd.println("CO2=");
    M5.Lcd.setTextSize(12);
    M5.Lcd.setCursor(80, 80);
    M5.Lcd.println((String)co2);
    M5.Lcd.setTextSize(4);
    M5.Lcd.setCursor(240, 140);
    M5.Lcd.println("ppm");

    // 温度
    M5.Lcd.setTextSize(3);
    M5.Lcd.setCursor(0, 170);
    M5.Lcd.println("Temp=" + (String)temp + "C");
    // 湿度
    M5.Lcd.setCursor(0, 200);
    M5.Lcd.println("Humidity=" + (String)hum + "%");
  }

  // 2000ミリ秒待機
  delay(2000);
}